@@ -14,7 +14,13 @@ class Project(Enum):
 
 
 class ProjectInfo:
-    def __init__(self, project: Project, deployment_key_name: str, client_key_name: str, base_url: str = None):
+    def __init__(
+        self,
+        project: Project,
+        deployment_key_name: str,
+        client_key_name: str,
+        base_url: str = None,
+    ):
         self.name: str = project.value
         self.deployment_key_name: str = deployment_key_name
         self.client_key_name: str = client_key_name
