@@ -30,7 +30,11 @@ def zip_and_upload(client: CogniteClient, code_path: Path, file_name: str, data_
         shutil.make_archive(str(zip_path), "zip", str(code_path))
         id = data_set_id(client, data_set_name)
         file = client.files.upload(
-            f"{zip_path}.zip", name=file_name, external_id=file_name, overwrite=True, data_set_id=id
+            f"{zip_path}.zip",
+            name=file_name,
+            external_id=file_name,
+            overwrite=True,
+            data_set_id=id,
         )
         counter = 0
         while client.files.retrieve(file.id) is None:
